Module http_client

Module http_client 

Core outbound HTTP client abstractions.

This module exists to support onion architecture: inner layers define traits and types, outer layers provide concrete implementations (e.g. reqwest in obzenflow_infra).

Re-exports

pub use client::HttpClient;
pub use error::HttpClientError;
pub use mock::MockHttpClient;
pub use response::HttpResponse;
pub use types::RequestSpec;
pub use crate::web::HttpMethod;

Modules

client
error
mock
response
types

Structs

Bytes
A cheaply cloneable and sliceable chunk of contiguous memory.
HeaderMap
A specialized multimap for header names and values.
Url
A parsed URL record.